@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # Copyright 2013 Rackspace Hosting
 # All Rights Reserved.
@@ -19,9 +17,9 @@
 from __future__ import print_function
 
 import os
-import re
 import sys
 import uuid
+import simplejson as json
 
 import six
 import prettytable
@@ -59,7 +57,7 @@ def add_arg(f, *args, **kwargs):
     # NOTE(sirp): avoid dups that can occur when the module is shared across
     # tests.
     if (args, kwargs) not in f.arguments:
-        # Because of the sematics of decorator composition if we just append
+        # Because of the semantics of decorator composition if we just append
         # to the options list positional options will appear to be backwards.
         f.arguments.insert(0, (args, kwargs))
 
@@ -114,7 +112,26 @@ def translate_keys(collection, convert):
                 setattr(item, to_key, item._info[from_key])
 
 
+def _output_override(objs, print_as):
+    """
+    If an output override global flag is set, print with override
+    raise BaseException if no printing was overridden.
+    """
+    if 'json_output' in globals() and json_output:
+        if print_as == 'list':
+            new_objs = []
+            for o in objs:
+                new_objs.append(o._info)
+        elif print_as == 'dict':
+            new_objs = objs
+        # pretty print the json
+        print(json.dumps(new_objs, indent='  '))
+    else:
+        raise BaseException('No valid output override')
+
+
 def _print(pt, order):
+
     if sys.version_info >= (3, 0):
         print(pt.get_string(sortby=order))
     else:
@@ -122,6 +139,11 @@ def _print(pt, order):
 
 
 def print_list(objs, fields, formatters={}, order_by=None):
+    try:
+        _output_override(objs, 'list')
+        return
+    except BaseException:
+        pass
     mixed_case_fields = []
     pt = prettytable.PrettyTable([f for f in fields], caching=False)
     pt.aligns = ['l' for f in fields]
@@ -146,6 +168,11 @@ def print_list(objs, fields, formatters={}, order_by=None):
 
 
 def print_dict(d, property="Property"):
+    try:
+        _output_override(d, 'dict')
+        return
+    except BaseException:
+        pass
     pt = prettytable.PrettyTable([property, 'Value'], caching=False)
     pt.aligns = ['l', 'l']
     [pt.add_row(list(r)) for r in six.iteritems(d)]
@@ -216,6 +243,18 @@ class HookableMixin(object):
             hook_func(*args, **kwargs)
 
 
+def safe_issubclass(*args):
+    """Like issubclass, but will just return False if not a class."""
+
+    try:
+        if issubclass(*args):
+            return True
+    except TypeError:
+        pass
+
+    return False
+
+
 # http://code.activestate.com/recipes/
 #   577257-slugify-make-a-string-usable-in-a-url-or-filename/
 def slugify(value):
@@ -228,3 +267,16 @@ def slugify(value):
     Make use strutils.to_slug from openstack common
     """
     return strutils.to_slug(value, incoming=None, errors="strict")
+
+
+def is_uuid_like(val):
+    """Returns validation of a value as a UUID.
+
+    For our purposes, a UUID is a canonical form string:
+    aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa
+
+    """
+    try:
+        return str(uuid.UUID(val)) == val
+    except (TypeError, ValueError, AttributeError):
+        return False
